import asyncio


##__________________________________________________________________||
def f():
    r = 0
    return r


def subject():
    f()
    f()
    return


##__________________________________________________________________||
async def a():
    await asyncio.sleep(0.1)
    return


def run_a():
    asyncio.run(a())


##__________________________________________________________________||
def gen():
    yield 1
    yield 2


def call_gen():
    for _ in gen():
        pass


##__________________________________________________________________||
def call_lambda():
    l = lambda x: x + 1  # noqa: E731, E741
    l(2)


##__________________________________________________________________||
